@@ -171,6 +171,9 @@ class Connection(object):
         self._transport.close()
         self._transport.open()
 
+    def query_cancel(self, query_id):
+        self._client.cancelQuery(queryId=query_id)
+
     def commit(self):
         """Hive does not support transactions, so this does nothing."""
         pass
@@ -266,6 +269,10 @@ class Cursor(common.DBAPICursor):
         """Clears the tmp data"""
         self.connection.clear(self._query_id)
 
+    def cancel(self):
+        _logger.info("Cancelling query")
+        self.connection.query_cancel(self._query_id)
+
     def execute(self, operation, parameters=None, **kwargs):
         """Prepare and execute a database operation (query or command).
         Return values are not defined.
@@ -291,10 +298,6 @@ class Cursor(common.DBAPICursor):
         _logger.info("fetch returning the rowcount from e6x itself")
         return self._rowcount
 
-    def cancel(self):
-        """Uniphi does not support cancelling of queries as yet"""
-        pass
-
     def _fetch_more(self):
         _logger.info("fetching batch")
         batch_size = self._arraysize
@@ -342,10 +345,11 @@ class Cursor(common.DBAPICursor):
             self.fetch_batch()
             if len(self._batch) == 0:
                 return None
-        _logger.info("lenght of batch: ", self._batch)
+        _logger.info("length of batch: ", self._batch)
         self.rows_count += len(self._batch)
+        _logger.info("Count: ", self.rows_count)
         if self.rows_count <= 1000:
-            _logger.info("e6x - Breaking the loop after 1000 e6x - fetch many records")
+            _logger.info("e6x - Breaking the loop after 1000 - fetch many records")
             return self._batch
         # batchRecords = self._batch
         # return batchRecords
@@ -390,7 +394,7 @@ if __name__ == '__main__':
                          ssl_cert=None,
                          thrift_transport=None)
     cursor = Cursor(connection)
-    cursor.execute("select * from date_dim;")
+    cursor.execute("select * from call_center;")
     bdata = cursor.fetchone()
     try:
         # if len(bdata) < 1000:
